Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2700)

Unified Diff: content/test/test_media_stream_client.h

Issue 18590002: Migrate MediaStream test code from content/shell/renderer/ to content/test/. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/test/layouttest_support.cc ('k') | content/test/test_media_stream_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/test/test_media_stream_client.h
diff --git a/content/shell/renderer/shell_media_stream_client.h b/content/test/test_media_stream_client.h
similarity index 64%
rename from content/shell/renderer/shell_media_stream_client.h
rename to content/test/test_media_stream_client.h
index df74532ac6f7f87d8cd7dd22da0ca3b82096d31e..ea872e2843f1387e3e5fae072e12650bb9830e6e 100644
--- a/content/shell/renderer/shell_media_stream_client.h
+++ b/content/test/test_media_stream_client.h
@@ -2,21 +2,23 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_SHELL_RENDERER_SHELL_MEDIA_STREAM_CLIENT_H_
-#define CONTENT_SHELL_RENDERER_SHELL_MEDIA_STREAM_CLIENT_H_
+#ifndef CONTENT_TEST_TEST_MEDIA_STREAM_CLIENT_H_
+#define CONTENT_TEST_TEST_MEDIA_STREAM_CLIENT_H_
#include "base/callback_forward.h"
+#include "content/public/renderer/render_view_observer.h"
#include "third_party/WebKit/public/platform/WebURL.h"
#include "webkit/renderer/media/media_stream_client.h"
namespace content {
// ShellMediaStreamClient is a mock implementation of
// webkit_media::MediaStreamClient used when running layout tests.
-class ShellMediaStreamClient : public webkit_media::MediaStreamClient {
+class TestMediaStreamClient : public RenderViewObserver,
+ public webkit_media::MediaStreamClient {
public:
- ShellMediaStreamClient();
- virtual ~ShellMediaStreamClient();
+ explicit TestMediaStreamClient(RenderView* render_view);
+ virtual ~TestMediaStreamClient();
// webkit_media::MediaStreamClient implementation.
virtual bool IsMediaStream(const GURL& url) OVERRIDE;
@@ -30,4 +32,4 @@ class ShellMediaStreamClient : public webkit_media::MediaStreamClient {
} // namespace content
-#endif // CONTENT_SHELL_RENDERER_SHELL_MEDIA_STREAM_CLIENT_H_
+#endif // CONTENT_TEST_TEST_MEDIA_STREAM_CLIENT_H_
« no previous file with comments | « content/test/layouttest_support.cc ('k') | content/test/test_media_stream_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,21 +2,23 @@
#include "webkit/renderer/media/media_stream_client.h"
namespace content {
-// ShellMediaStreamClient is a mock implementation of
+// TestMediaStreamClient is a mock implementation of
// webkit_media::MediaStreamClient used when running layout tests.
This is Rietveld 408576698